@@ -19,3 +19,7 @@
 
 #undef HAVE_DEVGTK
 
+#undef WITH_SYMBOL_UNDERSCORE
+
+#undef GNOME_ICONDIR
+
