@@ -3,6 +3,7 @@
 #include <config.h>
 #include <strings.h>
 #include "capplet-widget.h"
+#include <libgnomeui/gnome-window-icon.h>
 
 extern void background_init(void);
 
@@ -29,7 +30,7 @@ main (gint argc, char *argv[])
 	
 	init_results = gnome_capplet_init("background-properties", VERSION,
 					  argc, argv, options, 0, &ctx);
-
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-ccbackground.png");
 	if (init_results < 0) {
                 g_warning (_("an initialization error occurred while "
 			   "starting 'background-properties-capplet'.\n"
