@@ -547,19 +547,13 @@ static GtkWidget *wallp, *fill;
 static GtkWidget *scaledkeepButton, *centeredButton;
 
 static void
-set_enabled (GtkWidget *widget)
+set_enabled (GtkWidget *widget, gpointer data)
 {
-    if (!GTK_TOGGLE_BUTTON (widget)->active) {
-        /* Disabled */
-        gtk_widget_set_sensitive(wallp, FALSE);
-        gtk_widget_set_sensitive(fill, FALSE);
-        curState.enabled = FALSE;
-    } else {
-	gtk_widget_set_sensitive(wallp, TRUE);
-	gtk_widget_set_sensitive(fill, TRUE);
-        curState.enabled = TRUE;
-    }
-    fill_monitor (!ignoreChanges, &curState); 
+	gint a = GTK_TOGGLE_BUTTON (widget)->active;
+        gtk_widget_set_sensitive(wallp, a);
+        gtk_widget_set_sensitive(fill, a);
+	curState.enabled = a;
+	fill_monitor (!ignoreChanges, &curState); 
 }
     
 static void
@@ -1043,8 +1037,8 @@ background_apply (struct bgState *state)
     gnome_color_picker_set_i16 (GNOME_COLOR_PICKER(cp2), 
 				state->bgColor2.red, state->bgColor2.green,
 				state->bgColor2.blue, 0xff);
-    if (!state->enabled)
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radion), TRUE);
+
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radion), state->enabled);
 
     if (state->enabled) {
 	gtk_widget_set_sensitive(cp2, state->grad);
@@ -1094,7 +1088,7 @@ background_help(GtkWidget *widget, struct bgState *state)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccdesktop.html#GCCBACK");
+  tmp = gnome_help_file_find_file ("control-center", "desktop-intro.html#GCCBACK");
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
@@ -1156,8 +1150,7 @@ background_write (struct bgState *state)
 	      state->bgColor2.blue >> 8);
     gnome_config_set_string ("/Background/Default/color2", buffer);
 
-    gnome_config_set_string ("/Background/Default/Enabled",
-			     (state->enabled) ? "True" : "False");
+    gnome_config_set_bool ("/Background/Default/Enabled", state->enabled);
     gnome_config_set_string ("/Background/Default/simple",
 			     (state->grad) ? "gradient" : "solid");
     gnome_config_set_string ("/Background/Default/gradient",
@@ -1195,10 +1188,8 @@ background_read ( struct bgState *state )
 	b = state->bgColor2.blue >> 8;
 	state->bgColor2.pixel = gdk_imlib_best_color_match(&r, &g, &b);
   
-	state->enabled = !(strcasecmp
-		(gnome_config_get_string
-		 ("/Background/Default/Enabled=True"),
-		 "True"));
+	state->enabled = gnome_config_get_bool
+		("/Background/Default/Enabled=True");
 	state->bgType = (strcasecmp
 		  (gnome_config_get_string
 		   ("/Background/Default/type=simple"),
@@ -1323,12 +1314,10 @@ background_setup (struct bgState *state)
     gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), radion, FALSE, FALSE, 0);
-    
-    if (!state->enabled) {
-	    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radion), TRUE);
-	    gtk_widget_set_sensitive (fill, FALSE);
-	    gtk_widget_set_sensitive (wallp, FALSE);
-    }
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radion), state->enabled);
+    gtk_widget_set_sensitive (fill, state->enabled);
+    gtk_widget_set_sensitive (wallp, state->enabled);
 
     gtk_signal_connect (GTK_OBJECT(radion), "toggled",
 			(GtkSignalFunc) set_enabled,
@@ -1348,7 +1337,6 @@ background_setup (struct bgState *state)
 			GTK_SIGNAL_FUNC (background_ok), &curState);
 
     gtk_container_add(GTK_CONTAINER(capplet), vbox);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radion), TRUE);
     gtk_widget_show(capplet);
 }
 
