@@ -81,7 +81,7 @@ keyboard_help(void)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccperiph.html#GCCKEY");
+  tmp = gnome_help_file_find_file ("control-center", "peripherals.html#GCCKEY");
   if (tmp) {
           gnome_help_goto(0, tmp);
           g_free(tmp);
