@@ -4,7 +4,8 @@
  */
 #include <config.h>
 #include "capplet-widget.h"
-#include "gnome.h"
+#include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <string.h>
 #include <sys/types.h>
 #include <dirent.h>
@@ -65,7 +66,21 @@ cancel_callback ()
 static void
 help_callback ()
 {
-        /* Sigh... empty as always */
+  gchar *tmp;
+  
+  tmp = gnome_help_file_find_file ("control-center", "doc-handlers.html#GCCMIME");
+  if (tmp) {
+          gnome_help_goto(0, tmp);
+          g_free(tmp);
+  } else {
+          GtkWidget *mbox;
+          
+          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
+				 GNOME_MESSAGE_BOX_ERROR,
+				 _("Close"), NULL);
+    
+          gtk_widget_show(mbox);
+  }
 }
 
 static void
@@ -108,10 +123,8 @@ init_mime_capplet ()
                            GTK_SIGNAL_FUNC(hide_edit_window), NULL);
         gtk_signal_connect(GTK_OBJECT(capplet), "page_shown",
                            GTK_SIGNAL_FUNC(show_edit_window), NULL);
-#if 0
         gtk_signal_connect(GTK_OBJECT(capplet), "help",
                            GTK_SIGNAL_FUNC(help_callback), NULL);
-#endif
 }
 
 int
@@ -125,6 +138,7 @@ main (int argc, char **argv)
         init_results = gnome_capplet_init("mime-type-capplet", VERSION,
                                           argc, argv, NULL, 0, NULL);
 
+        gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-ccmime.png");
 	if (init_results < 0) {
                 exit (0);
 	}
