@@ -13,7 +13,7 @@
 #include "gnome.h"
 
 /* Maximum number of mouse buttons we handle.  */
-#define MAX_BUTTONS 10
+#define MAX_BUTTONS 32
 
 /* Half the number of acceleration levels we support.  */
 #define MAX_ACCEL 5
@@ -101,7 +101,7 @@ mouse_help (void)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccperiph.html#GCCMOUSE");
+  tmp = gnome_help_file_find_file ("control-center", "peripherals.html#GCCMOUSE");
   if (tmp) {
           gnome_help_goto(0, tmp);
           g_free(tmp);
