@@ -89,7 +89,7 @@ enum {
   NSIGNALS2
 };
 
-static gint gsm_session_signals[NSIGNALS2];
+static guint gsm_session_signals[NSIGNALS2];
 static GtkObjectClass *parent_class = NULL;
 
 static void
@@ -131,15 +131,15 @@ gsm_session_object_init (GsmSession* session)
   session->waiting     = -1;
 }
 
-GtkTypeInfo gsm_session_info = 
+static GtkTypeInfo gsm_session_info = 
 {
   "GsmSession",
   sizeof (GsmSession),
   sizeof (GsmSessionClass),
   (GtkClassInitFunc) gsm_session_class_init,
   (GtkObjectInitFunc) gsm_session_object_init,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL,
+  NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -216,7 +216,6 @@ static void
 gsm_session_destroy (GtkObject *o)
 {
   GsmSession* session = (GsmSession*)o;
-  guint i, j;
 
   g_return_if_fail(session != NULL);
   g_return_if_fail(GSM_IS_SESSION(session));
@@ -290,7 +289,7 @@ enum {
   NSIGNALS
 };
 
-static gint gsm_client_signals[NSIGNALS];
+static guint gsm_client_signals[NSIGNALS];
 static void client_reasons (GsmClient* client, gboolean confirm, 
 			    GSList* reasons);
 
@@ -362,7 +361,7 @@ gsm_client_object_init (GsmClient* client)
 {
   client->handle = NULL;
   client->session = (GsmSession*)live_session;
-  client->order = 50;
+  client->order = DEFAULT_PRIORITY;
   client->style = GSM_NORMAL;
   client->state = GSM_INACTIVE;
   client->command = NULL;
@@ -375,8 +374,7 @@ GtkTypeInfo gsm_client_info =
   sizeof (GsmClientClass),
   (GtkClassInitFunc) gsm_client_class_init,
   (GtkObjectInitFunc) gsm_client_object_init,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL, NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -416,7 +414,6 @@ static void
 gsm_client_destroy (GtkObject *o)
 {
   GsmClient* client;
-  guint i, j;
 
   g_return_if_fail(o != NULL);
   g_return_if_fail(GSM_IS_CLIENT(o));
@@ -530,7 +527,7 @@ enum {
   NSIGNALS3
 };
 
-static gint gsm_protocol_signals[NSIGNALS3];
+static guint gsm_protocol_signals[NSIGNALS3];
 
 static void
 gsm_protocol_class_init (GsmProtocolClass *klass)
@@ -569,8 +566,8 @@ GtkTypeInfo gsm_protocol_info =
   sizeof (GsmProtocolClass),
   (GtkClassInitFunc) gsm_protocol_class_init,
   (GtkObjectInitFunc) NULL,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL,
+  NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -618,7 +615,6 @@ static void
 gsm_protocol_destroy (GtkObject *o)
 {
   GsmProtocol* protocol = (GsmProtocol*)o;
-  guint i, j;
 
   g_return_if_fail(protocol != NULL);
   g_return_if_fail(protocol == the_protocol);
@@ -652,6 +648,30 @@ gsm_protocol_get_last_session (GsmProtocol* protocol)
 			     GsmGetLastSession, NULL), NULL);  
 }
 
+void 
+gsm_protocol_set_trash_mode (GsmProtocol *protocol,
+			     gboolean     trash)
+{
+  SmProp prop;
+  SmPropValue vals[2];
+
+  g_return_if_fail(protocol != NULL);
+  g_return_if_fail(GSM_IS_PROTOCOL (protocol));
+
+  vals[0].length = strlen (GsmTrashMode);
+  vals[0].value = GsmTrashMode;
+
+  vals[1].length = 1;
+  vals[1].value = trash ? "1" : "0";
+
+  prop.name = GsmCommand;
+  prop.type = SmLISTofARRAY8;
+  prop.num_vals = 2;
+  prop.vals = vals;
+  
+  command (protocol, &prop, NULL);
+}
+
 /* Public utilities */
 gboolean   gsm_sh_quotes_balance (gchar* sh)
 {
@@ -900,7 +920,6 @@ dispatch_event (SmcConn smc_conn, SmPointer data,
 		   reads)
 	    {
 	      GsmSession* session = (GsmSession*)reads->data;
-	      GSList *list = NULL;
 	      gint i;
 
 	      session->handle = g_strdup (GSM_COMMAND_ARG1 (props[0]));
