@@ -13,6 +13,7 @@
 #include <gtk/gtk.h>
 #include "capplet-widget.h"
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 /* use this flag so we don't tell control center of changes that it */
 /* shouldn't turn on Try/Revert because we changed it, not the user */
@@ -89,7 +90,7 @@ main(int argc, char *argv[])
 
     init_results = gnome_capplet_init("sound-properties", VERSION,
                                       argc, argv, NULL, 0, NULL);
-
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-audio2.png");
     if (init_results < 0)
         g_error (_("an initialization error occurred while "
                  "starting 'sound-properties-capplet'."));
@@ -310,7 +311,7 @@ sound_properties_create(void)
                          gtk_clist_columns_autosize(GTK_CLIST(retval->ctree)),
                          250);
 
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(wtmp), retval->ctree);
+    gtk_container_add(GTK_CONTAINER(wtmp), retval->ctree);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(wtmp), GTK_POLICY_AUTOMATIC,
                                    GTK_POLICY_ALWAYS);
     gtk_table_attach_defaults(GTK_TABLE(table), wtmp, 0, 2, 0, 1);
@@ -680,7 +681,7 @@ ui_do_help(void)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccmm.html#GCCSOUND");
+  tmp = gnome_help_file_find_file ("control-center", "multimedia-intro.html#MULTIMEDIA-SOUND");
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
