@@ -1,6 +1,7 @@
 #include <config.h>
 #include "da.h"
 #include "capplet-widget.h"
+#include <libgnomeui/gnome-window-icon.h>
 #include <signal.h>
 
 static gboolean   ignore_change = FALSE;
@@ -113,6 +114,7 @@ install_theme_callback (GtkWidget *widget, gpointer data)
   gtk_widget_set_sensitive (widget, FALSE);
 
   install_theme_file_sel = gtk_file_selection_new (_("Select a theme to install"));
+  gnome_window_icon_set_from_default (GTK_WINDOW (install_theme_file_sel));
   gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (install_theme_file_sel));
   /* BEGIN UGLINESS.  This code is stolen from gnome_dialog_set_parent.
    * We want its functionality, but it takes a GnomeDialog as its argument.
@@ -345,12 +347,13 @@ click_preview(GtkWidget *widget, gpointer data)
 
   send_reread();
 }
+
 static void
 click_help(GtkWidget *widget, gpointer data)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("users-guide", "gccdesktop.html#GCCTHEME");
+  tmp = gnome_help_file_find_file ("control-center", "desktop-intro.html#GCCTHEME");
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
@@ -363,7 +366,6 @@ click_help(GtkWidget *widget, gpointer data)
     
     gtk_widget_show(mbox);
   }
-
 }
 static void
 click_try(GtkWidget *widget, gpointer data)
