@@ -1,5 +1,6 @@
 #include <config.h>
 #include "capplet-widget.h"
+#include <libgnomeui/gnome-window-icon.h>
 #include "da.h"
 
 #define THEME_SWITCHER_VERSION "0.1"
@@ -21,7 +22,8 @@ main(int argc, char **argv)
 	  exit (1);
   case 1:
 	  return 0;
-  }  
+  }
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-ccthemes.png");
   w = make_main();
   gtk_widget_show_all(w);
   send_socket();
