@@ -15,7 +15,7 @@ extern "C" {
 
 void launch_capplet (node_data *data, gboolean exec_new);
 node_data *find_node_by_id (gint id);
-void revert_all ();
+void revert_all (void);
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
